"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const mkdir = util_1.promisify(fs_1.default.mkdir);
const readFile = util_1.promisify(fs_1.default.readFile);
async function getDotfile(title) {
    if (process.env.CORE_D_DOTFILE) {
        return process.env.CORE_D_DOTFILE;
    }
    if (process.env.HOME && process.env.XDG_CONFIG_HOME) {
        const confDir = path_1.default.join(process.env.XDG_CONFIG_HOME, title);
        await mkdir(confDir, { recursive: true });
        const confPath = path_1.default.join(confDir, title);
        return path_1.default.relative(process.env.HOME, confPath);
    }
    return ".prettierd";
}
async function main(cmdOrFilename) {
    const title = "prettierd";
    process.env.CORE_D_TITLE = title;
    process.env.CORE_D_SERVICE = require.resolve("./service");
    process.env.CORE_D_DOTFILE = await getDotfile(title);
    const core_d = require("core_d");
    if (cmdOrFilename === "start" ||
        cmdOrFilename === "stop" ||
        cmdOrFilename === "restart" ||
        cmdOrFilename === "status") {
        core_d[cmdOrFilename]();
        return;
    }
    core_d.invoke([cmdOrFilename], await readFile(process.stdin.fd, { encoding: "utf-8" }));
}
main(process.argv[2]).catch((err) => {
    console.error(err);
    process.exit(1);
});
